﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BingMapsSample.BingCommonService;
using System.Net;
using BingMapsSample.BingImageryService;

namespace BingMapsSample
{
    public partial class Form1 : Form
    {

        private Medo.IO.Gps gps = new Medo.IO.Gps();
        private string ClientToken { get; set; }


        public Form1()
        {
            InitializeComponent();
        }




        private void Form1_Load(object sender, EventArgs e)
        {
            CommonService commonService = new CommonService();
            commonService.Url = "https://staging.common.virtualearth.net/find-30/common.asmx";
            commonService.Credentials = new System.Net.NetworkCredential(Program.BingMapUserID, Program.BingMapUserPassword);

            TokenSpecification tokenSpecification = new TokenSpecification();
            tokenSpecification.ClientIPAddress = "0.0.0.0";
            tokenSpecification.TokenValidityDurationMinutes = 480; //maximum

            this.ClientToken = commonService.GetClientToken(tokenSpecification);



            this.gps.Open();
            tmrUpdate_Tick(null, null);
        }


        private Uri GetMapImageUri(double latitude, double longitude)
        {
            MapUriRequest mapUriRequest = new MapUriRequest();

            mapUriRequest.Credentials = new BingImageryService.Credentials();
            mapUriRequest.Credentials.Token = ClientToken;

            mapUriRequest.Center = new BingImageryService.Location();
            mapUriRequest.Center.Latitude = latitude;
            mapUriRequest.Center.Longitude = longitude;
            mapUriRequest.Center.LatitudeSpecified = true;
            mapUriRequest.Center.LongitudeSpecified = true;

            mapUriRequest.Options = new MapUriOptions();
            mapUriRequest.Options.ImageType = ImageType.Jpeg;
            mapUriRequest.Options.ZoomLevel = 13;
            mapUriRequest.Options.ImageTypeSpecified = true;
            mapUriRequest.Options.ZoomLevelSpecified = true;

            mapUriRequest.Options.ImageSize = new BingImageryService.SizeOfint();
            mapUriRequest.Options.ImageSize.Width = map.Width;
            mapUriRequest.Options.ImageSize.Height = map.Height;
            mapUriRequest.Options.ImageSize.WidthSpecified = true;
            mapUriRequest.Options.ImageSize.HeightSpecified = true;


            BingImageryService.ImageryService imageryService = new ImageryService();
            MapUriResponse mapUriResponse = imageryService.GetMapUri(mapUriRequest);

            if (mapUriResponse.ResponseSummary.StatusCode == ResponseStatusCode.Success)
            {
                string uri = mapUriResponse.Uri.Replace("{token}", ClientToken);
                return new Uri(mapUriResponse.Uri);
            }
            else
            {
                return null;
            }
        }

        private void menuItem1_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void tmrUpdate_Tick(object sender, EventArgs e)
        {
            var position = gps.GetPosition();
            if (position.Latitude.HasValue && position.Longitude.HasValue)
            {
                txtLocation.Text = string.Format("{0:0.00000}, {1:0.00000}", position.Latitude.Value, position.Longitude.Value);
                var request = WebRequest.Create(GetMapImageUri(position.Latitude.Value, position.Longitude.Value));
                using (var response = request.GetResponse())
                {
                    map.Image = new Bitmap(response.GetResponseStream());
                }
            }
            else
            {
                txtLocation.Text = "";
                map.Image = null;
            }
        }

        private void Form1_Closing(object sender, CancelEventArgs e)
        {
            this.gps.Close();
        }

    }
}